@@ -197,8 +197,13 @@ test(ieee_div) :- %%, blocked(fail)) :-
     assertion(    0.0 is -1.0/ -inf),
     assertion( 1.5NaN is -1.0/ nan),
     assertion( 1.5NaN is  nan/ 1.0),
+    assertion( 1.5NaN is  nan/ 0),
+    assertion( 1.0Inf is  inf/ 0),
+    assertion(-1.0Inf is -inf/ 0),
+    assertion( 1.0Inf is    1/ 0),
+    assertion(-1.0Inf is -1r2/ 0),
     assertion(fp_error(X is 1/0,float_zero_div)),
-    assertion(fp_error(X is 1/0.0,float_overflow)),
+    assertion(fp_error(X is 1/0.0,float_zero_div)),
     assertion(fp_error(X is -inf/ -inf,float_undefined)),
     assertion(fp_error(X is -inf/1.0,float_overflow)).
 
@@ -379,12 +384,13 @@ test(ieee_pow) :-                                       % C11 - F.10.4.4
     assertion(    1.0 is  1.0**  inf),
     assertion(    1.0 is  1.0** (-inf)),
     assertion(    1.0 is  1.0**  nan),
-    assertion(    1.0 is  inf**  0.0),
-    assertion(    1.0 is (-inf)**  0.0),
-    assertion(    1.0 is  nan**  0.0),
-    assertion(    1.0 is  inf** -0.0),
-    assertion(    1.0 is (-inf)** -0.0),
-    assertion(    1.0 is  nan** -0.0),
+    assertion( 1.5NaN is  0**  nan),
+    assertion(      1 is  inf**  0.0),
+    assertion(      1 is  (-inf)**  0.0),
+    assertion(      1 is  nan**  0.0),
+    assertion(      1 is  inf** -0.0),
+    assertion(      1 is  (-inf)** -0.0),
+    assertion(      1 is  nan** -0.0),
     assertion( 1.5NaN is -1.0**  1.5),
 
     assertion( 1.0Inf is -0.5** (-inf)),
@@ -504,19 +510,44 @@ test(ieee_min) :-                                       % C11 - F.10.9.3
 %% End of Annex F Tests %%%%%%%%%%%%%%%%%%%%%%%%%
 
 test(ieee_rmode) :-
-	assertion(rounding(-1/(3),_)),
-	assertion(rounding(sqrt(2),_)),
-	assertion(rounding(exp(log(2)),_)),
-	assertion(rounding(pi,_)),
-	assertion(rounding(e,_)).
+    assertion(test_rounding(-1.0/(3))),
+    assertion(test_rounding(sqrt(2))),
+    assertion(test_rounding(exp(log(2)))),
+    assertion(test_rounding(-2.0** 1r3)),
+    assertion(test_rounding( 2.0** 1r3)),
+    assertion(test_rounding(pi)),
+    assertion(test_rounding(e)).
 
 test(ieee_rndto) :-
-	assertion(roundto(-1/(3),_)),
-	assertion(roundto(sqrt(2),_)),
-	assertion(roundto(exp(log(2)),_)),
-	assertion(roundto(2**0.5,_)),
-	assertion(rounding(pi,_)),
-	assertion(rounding(e,_)).
+    assertion(test_roundto(-1.0/(3))),
+    assertion(test_roundto(sqrt(2))),
+    assertion(test_roundto(exp(log(2)))),
+    assertion(test_roundto(2**0.5)),
+    assertion(test_roundto(-2.0** 1r3)),
+    assertion(test_roundto( 2.0** 1r3)),
+    assertion(test_roundto(pi)),
+    assertion(test_roundto(e)).
+
+test(bounded) :-
+    assertion(bounded_number(0,10,1)),
+    assertion(\+(bounded_number(0,1r2,1))),
+    assertion(bounded_number(0.0,10.0,1)),
+    assertion(bounded_number(0,10,1.0)),
+    assertion(bounded_number(0.0,10.0,1.0)),
+    assertion(bounded_number(0,10,1r2)),
+    assertion(bounded_number(0.0,10.0,1r2)),
+    assertion(bounded_number(1r3,2r3,1r2)),
+    assertion(bounded_number(-2r3,-1r3,-1r2)),
+    assertion((bounded_number(L,H,-0.0),bounded_number(L,H,0.0))),
+    assertion((bounded_number(L,H,-1.0),bounded_number(L,H,-1.0))),
+    assertion((bounded_number(L,H,-1),[L,H]=[-2,0])),
+    assertion((bounded_number(L,H,-1.0),[L,H]=[-1.0000000000000002,-0.9999999999999999])),
+    assertion((bounded_number(L,H,-1r2),[L,H]=[-0.5000000000000001,-0.49999999999999994])),
+    assertion((bounded_number(L,H,10000000000000000000), [L,H]=[9999999999999999999,10000000000000000001])),
+    assertion(\+(bounded_number(L,H,1.0Inf))),
+    assertion(\+(bounded_number(L,H,-1.0Inf))),
+    assertion(\+(bounded_number(L,H,1.5NaN))).
+
 
 :- end_tests(ieee754).
 
@@ -535,29 +566,47 @@ float_parts(F,Ip,Fp) :-
     Ip is float_integer_part(F),
     Fp is float_fractional_part(F).
 
-rounding(Exp,[Rc,Rp,Rn,Rz]) :- % for non-precise Exp
-    current_prolog_flag(float_rounding,Save),
+
+test_rounding(Exp) :-
+    rounding(Exp, Rounded),
+    check_round(Exp, Rounded).
+
+rounding(Exp,r(Rc,Rp,Rn,Rz)) :-                 % for non-precise Exp
+    current_prolog_flag(float_rounding, Save),
     set_prolog_flag(float_rounding,to_nearest),  Rc is Exp,
     set_prolog_flag(float_rounding,to_positive), Rp is Exp,
     set_prolog_flag(float_rounding,to_negative), Rn is Exp,
     set_prolog_flag(float_rounding,to_zero),     Rz is Exp,
-    set_prolog_flag(float_rounding,Save),
-    check_round([Rc,Rp,Rn,Rz]).
+    set_prolog_flag(float_rounding, Save).
 
-roundto(Exp,[Rc,Rp,Rn,Rz]) :- % for non-precise Exp
+test_roundto(Exp) :-
+    roundto(Exp, Rounded),
+    check_round(Exp, Rounded).
+
+roundto(Exp,r(Rc,Rp,Rn,Rz)) :-                  % for non-precise Exp
     Rc is roundtoward(Exp,to_nearest),
     Rp is roundtoward(Exp,to_positive),
     Rn is roundtoward(Exp,to_negative),
-    Rz is roundtoward(Exp,to_zero),
-    check_round([Rc,Rp,Rn,Rz]).
+    Rz is roundtoward(Exp,to_zero).
 
-check_round([Rc,Rp,Rn,Rz]) :-
+%!  check_round(+Exp, +Round)
+%
+%   Round is a term r(Nearest, Positive, Negative, Zero)
+
+check_round(Exp, r(Rc,Rp,Rn,Rz)) :-
     Rn =< Rc, Rc =< Rp,
-    (Rc < 0
-     -> (Rz >= Rc, Rz =:= Rp, Rz > Rn)
-      ; (Rz =< Rc, Rz =:= Rn, Rz < Rp)
+    (   Rc < 0
+    ->  Rz >= Rc, expect_less_then(Exp, n=Rn, z=Rz)
+    ;   Rz =< Rc, expect_less_then(Exp, z=Rz, p=Rp)
     ),
-    Rn < Rp.
+    expect_less_then(Exp, n=Rn, p=Rp).
+
+expect_less_then(Exp, A=X, B=Y) :-
+    (   X < Y
+    ->  true
+    ;   X == Y
+    ->  print_message(warning, ieee754_bounds(Exp, A-X, B-Y))
+    ).
 
 fp_error(Exp,FP_flag) :-
     get_set_flag(FP_flag,Save,error),
@@ -569,3 +618,10 @@ fp_error(Exp,FP_flag) :-
 fp_exception(float_overflow,FP_exception)  :- FP_exception==float_overflow.
 fp_exception(float_zero_div,FP_exception)  :- FP_exception==zero_divisor.
 fp_exception(float_undefined,FP_exception) :- FP_exception==undefined.
+
+:- multifile prolog:message//1.
+
+prolog:message(ieee754_bounds(Exp, A-X, B-Y)) -->
+    [ 'IEEE 754 dubious rounding: ~p: ~w = ~q, ~w = ~q'-
+      [Exp, A, X, B, Y]
+    ].
