@@ -160,6 +160,8 @@ const debug_topic debug_topics[] =
   DEBUG_TOPIC(MSG_CGC_CONSIDER),
   DEBUG_TOPIC(MSG_CGC_STACK),
   DEBUG_TOPIC(MSG_CGC_PRED_REF),
+  DEBUG_TOPIC(MSG_CGC_RETRACT),
+  DEBUG_TOPIC(MSG_CGC_GENERATION),
 
   DEBUG_TOPIC(MSG_JIT),
   DEBUG_TOPIC(MSG_JIT_DELINDEX),
