@@ -109,37 +109,6 @@ COMMON(int)		is_volatile_atom(atom_t a);
 COMMON(word)		pl_track_atom(term_t which, term_t stream);
 #endif
 
-/* pl-arith.c */
-
-COMMON(int)		ar_compare(Number n1, Number n2, int what);
-COMMON(int)		ar_compare_eq(Number n1, Number n2);
-COMMON(int)		pl_ar_add(Number n1, Number n2, Number r);
-COMMON(int)		ar_mul(Number n1, Number n2, Number r);
-COMMON(word)		pl_current_arithmetic_function(term_t f, control_t h);
-COMMON(void)		initArith(void);
-COMMON(void)		cleanupArith(void);
-COMMON(int)		indexArithFunction(functor_t fdef);
-COMMON(functor_t)	functorArithFunction(unsigned int n);
-COMMON(bool)		ar_func_n(int findex, int argc ARG_LD);
-COMMON(int)		ar_add_ui(Number n, intptr_t add);
-COMMON(int)		valueExpression(term_t p, Number n ARG_LD);
-COMMON(int)		toIntegerNumber(Number n, int flags);
-COMMON(int)		arithChar(Word p ARG_LD);
-COMMON(int)		getCharExpression(Word p, Number r ARG_LD);
-COMMON(Number)		growArithStack(ARG1_LD);
-COMMON(void)		freeArithLocalData(PL_local_data_t *ld);
-COMMON(int)		ar_sign_i(Number n1);
-COMMON(int)		ar_signbit(Number n1);
-COMMON(int)		check_float(Number n);
-COMMON(int)		ar_rdiv_mpz(Number n1, Number n2, Number r);
-COMMON(int)		PL_eval_expression_to_int64_ex(term_t t, int64_t *val);
-COMMON(int)		is_arith_flag(atom_t k);
-COMMON(int)		get_arith_flag(term_t val, atom_t k ARG_LD);
-COMMON(int)		set_arith_flag(term_t val, atom_t k ARG_LD);
-COMMON(void)		set_rounding(int mode);
-COMMON(int)		atom_to_rounding(atom_t a, int *m);
-COMMON(atom_t)		float_rounding_name(int m);
-
 /* pl-bag.c */
 COMMON(void)		markAtomsFindall(PL_local_data_t *ld);
 
@@ -195,7 +164,7 @@ COMMON(int)		addClauseToIndexes(Definition def, Clause cl,
 					   ClauseRef where);
 COMMON(void)		delClauseFromIndex(Definition def, Clause cl);
 COMMON(void)		cleanClauseIndexes(Definition def, ClauseList cl,
-					   gen_t active);
+					   DirtyDefInfo ddi, gen_t start);
 COMMON(void)		clearTriedIndexes(Definition def);
 COMMON(void)		unallocClauseIndexTable(ClauseIndex ci);
 COMMON(void)		deleteActiveClauseFromIndexes(Definition def, Clause cl);
@@ -336,7 +305,6 @@ COMMON(void)		clearLocalVariablesFrame(LocalFrame fr);
 COMMON(void)		setLTopInBody(void);
 COMMON(word)		check_foreign(void);	/* DEBUG(CHK_SECURE...) stuff */
 COMMON(void)		markAtomsOnStacks(PL_local_data_t *ld);
-COMMON(void)		set_min_generation(DirtyDefInfo ddi, gen_t gen);
 COMMON(void)		markPredicatesInEnvironments(PL_local_data_t *ld);
 COMMON(QueryFrame)	queryOfFrame(LocalFrame fr);
 COMMON(void)		mark_active_environment(struct bit_vector *active,
@@ -545,6 +513,9 @@ COMMON(int)		setDynamicDefinition(Definition def, bool isdyn);
 COMMON(int)		setThreadLocalDefinition(Definition def, bool isdyn);
 COMMON(int)		setAttrDefinition(Definition def, unsigned attr, int val);
 COMMON(int)		PL_meta_predicate(predicate_t def, const char*);
+COMMON(void)		ddi_add_access_gen(DirtyDefInfo ddi, gen_t access);
+COMMON(int)		ddi_contains_gen(DirtyDefInfo ddi, gen_t access);
+COMMON(int)		ddi_is_garbage(DirtyDefInfo ddi, gen_t start, Clause cl);
 
 /* pl-srcfile.c */
 
