@@ -886,7 +886,7 @@ with one operation, it turns out to be faster as well.
 #define P_NEW			SPY_ME
 #define P_NO_CLAUSES		TRACE_ME
 
-/* Flags on clauses (packed in unsigned flags : 8) */
+/* Flags on clauses (unsigned int) */
 
 #define CL_ERASED		(0x0001) /* clause was erased */
 #define UNIT_CLAUSE		(0x0002) /* Clause has no body */
@@ -898,6 +898,11 @@ with one operation, it turns out to be faster as well.
 #define CL_BODY_CONTEXT		(0x0080) /* Module context of body is different */
 					 /* from predicate */
 
+/* Flags on a DDI (Dirty Definition Info struct */
+
+#define DDI_MARKING		0x0001	 /* Actively using the DDI */
+#define DDI_INTERVALS		0x0002	 /* DDI collects an interval */
+
 /* Flags on module.  Most of these flags are copied to the read context
    in pl-read.c.
 */
@@ -1484,8 +1489,13 @@ struct definition_chain
   DefinitionChain	next;		/* next in chain */
 } definition_chain;
 
+#define PROC_DIRTY_GENS	10
+
 struct dirty_def_info
-{ gen_t		oldest_generation;	/* Oldest generation seen */
+{ unsigned short count;			/* # captured generations */
+  unsigned short flags;			/* DDI_* */
+  Definition	predicate;		/* The dirty predicate */
+  gen_t		access[PROC_DIRTY_GENS];/* Accessed generations */
 };
 
 typedef struct definition_ref
