@@ -559,82 +559,6 @@ ensureStackSpace__LD(size_t gcells, size_t tcells, int flags ARG_LD)
 }
 
 
-		 /*******************************
-		 *	     ARITHMETIC		*
-		 *******************************/
-
-static inline Number
-allocArithStack(ARG1_LD)
-{ if ( unlikely(LD->arith.stack.top == LD->arith.stack.max) )
-    return growArithStack(PASS_LD1);
-
-  return LD->arith.stack.top++;
-}
-
-static inline void
-pushArithStack(Number n ARG_LD)
-{ Number np = allocArithStack(PASS_LD1);
-
-  *np = *n;				/* structure copy */
-}
-
-static inline void
-resetArithStack(ARG1_LD)
-{ LD->arith.stack.top = LD->arith.stack.base;
-}
-
-static inline Number
-argvArithStack(int n ARG_LD)
-{ DEBUG(0, assert(LD->arith.stack.top - n >= LD->arith.stack.base));
-
-  return LD->arith.stack.top - n;
-}
-
-static inline void
-popArgvArithStack(int n ARG_LD)
-{ DEBUG(0, assert(LD->arith.stack.top - n >= LD->arith.stack.base));
-
-  for(; n>0; n--)
-  { LD->arith.stack.top--;
-    clearNumber(LD->arith.stack.top);
-  }
-}
-
-		 /*******************************
-		 *	      MPZ/MPQ		*
-		 *******************************/
-
-static inline int
-isMPQNum__LD(word w ARG_LD)
-{ if ( tagex(w) == (TAG_INTEGER|STG_GLOBAL) )
-  { Word p = addressIndirect(w);
-    size_t wsize = wsizeofInd(*p);
-
-    if ( wsize == WORDS_PER_INT64 )
-      return FALSE;
-
-    return p[1]&MP_RAT_MASK;
-  }
-
-  return FALSE;
-}
-
-static inline int
-isMPZNum__LD(word w ARG_LD)
-{ if ( tagex(w) == (TAG_INTEGER|STG_GLOBAL) )
-  { Word p = addressIndirect(w);
-    size_t wsize = wsizeofInd(*p);
-
-    if ( wsize == WORDS_PER_INT64 )
-      return FALSE;
-
-    return !(p[1]&MP_RAT_MASK);
-  }
-
-  return FALSE;
-}
-
-
 		 /*******************************
 		 *	      THREADS		*
 		 *******************************/
